@@ -6,7 +6,7 @@
 # With many thanks to Tobias Engel for his help and support!
 #
 #
-# sFlow.pm - 2007/03/20
+# sFlow.pm - 2007/09/13
 #
 # Please send comments or bug reports to <sflow@ams-ix.net>
 #
@@ -40,7 +40,7 @@ require Exporter;
 use Math::BigInt;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our @EXPORT_OK = qw(decode);
 
 
@@ -1175,13 +1175,16 @@ sub _decodeHeaderData {
 
   my($sm_lo, $sm_hi, $dm_lo, $dm_hi, $ipdata);
 
-  ($dm_hi, $dm_lo, $sm_hi, $sm_lo, $sFlowSample->{HeaderType}, $ipdata) = 
-    unpack('NnNnH4a*', $sFlowSample->{HeaderBin});
+
+ # ($dm_hi, $dm_lo, $sm_hi, $sm_lo, $sFlowSample->{HeaderType}, $ipdata) = 
+  ($sFlowSample->{HeaderEtherDestMac}, $sFlowSample->{HeaderEtherSrcMac}, $sFlowSample->{HeaderType}, $ipdata) = 
+#    unpack('NnNnH4a*', $sFlowSample->{HeaderBin});
+    unpack('a6a6H4a*', $sFlowSample->{HeaderBin});
 
   # Convert MAC addresses to hex string to avoid representation problems
 
-  $sFlowSample->{HeaderEtherSrcMac} = sprintf("%08x%04x", $sm_hi, $sm_lo);
-  $sFlowSample->{HeaderEtherDestMac} = sprintf("%08x%04x", $dm_hi, $dm_lo);
+#  $sFlowSample->{HeaderEtherSrcMac} = $sm_hi . $sm_lo; #sprintf("%08x%04x", $sm_hi, $sm_lo);
+#  $sFlowSample->{HeaderEtherDestMac} = $dm_hi. $dm_lo; #sprintf("%08x%04x", $dm_hi, $dm_lo);
 
 
   # analyze ether type
@@ -1958,6 +1961,7 @@ sub _decodeCounterGeneric {
   my $ifInOctets2 = undef;
   my $ifOutOctets1 = undef;
   my $ifOutOctets2 = undef;
+  my $ifStatus = undef;
 
   $sFlowSample->{COUNTERGENERIC} = 'COUNTERGENERIC';
 
@@ -1967,15 +1971,13 @@ sub _decodeCounterGeneric {
    $ifSpeed1,
    $ifSpeed2,
    $sFlowSample->{ifDirection},
-   $sFlowSample->{ifAdminStatus},
-   $sFlowSample->{ifOperStatus},
-   undef,
+   $ifStatus,
    $ifInOctets1,
    $ifInOctets2,
    $sFlowSample->{ifInUcastPkts},
    $sFlowSample->{ifInMulticastPkts},
    $sFlowSample->{ifInBroadcastPkts},
-   $sFlowSample->{idInDiscards},
+   $sFlowSample->{ifInDiscards},
    $sFlowSample->{ifInErrors},
    $sFlowSample->{ifInUnknownProtos},
    $ifOutOctets1,
@@ -1986,7 +1988,7 @@ sub _decodeCounterGeneric {
    $sFlowSample->{ifOutDiscards},
    $sFlowSample->{ifOutErrors},
    $sFlowSample->{ifPromiscuousMode}) = 
-    unpack("a$offset N5B1B1B30N16", $sFlowDatagramPacked);
+    unpack("a$offset N22", $sFlowDatagramPacked);
 
   $offset += 88;
 
@@ -1994,14 +1996,19 @@ sub _decodeCounterGeneric {
   $sFlowSample->{ifSpeed} = $sFlowSample->{ifSpeed} << 32;
   $sFlowSample->{ifSpeed} += $ifSpeed2;
  
-  $sFlowSample->{idInOctets} = Math::BigInt->new("$ifInOctets1");
-  $sFlowSample->{idInOctets} = $sFlowSample->{idInOctets} << 32;
-  $sFlowSample->{idInOctets} += $ifInOctets2;
+  $sFlowSample->{ifInOctets} = Math::BigInt->new("$ifInOctets1");
+  $sFlowSample->{ifInOctets} = $sFlowSample->{ifInOctets} << 32;
+  $sFlowSample->{ifInOctets} += $ifInOctets2;
 
   $sFlowSample->{ifOutOctets} = Math::BigInt->new("$ifOutOctets1");
   $sFlowSample->{ifOutOctets} = $sFlowSample->{ifOutOctets} << 32;
   $sFlowSample->{ifOutOctets} += $ifOutOctets2;
-  
+
+  # seperate the 32bit status
+  # thanks to wogri for this fix  
+  $sFlowSample->{ifAdminStatus} = $ifStatus & 0x1; 
+  $sFlowSample->{ifOperStatus} = ($ifStatus >> 1) & 0x1;
+
   $$offsetref = $offset;
 }
 
@@ -2574,11 +2581,11 @@ Counter generic:
   ifDirection
   ifAdminStatus
   ifOperStatus
-  idInOctets
+  ifInOctets
   ifInUcastPkts
   ifInMulticastPkts
   ifInBroadcastPkts
-  idInDiscards
+  ifInDiscards
   ifInErrors
   ifInUnknownProtos
   ifOutOctets
